summaryrefslogtreecommitdiff
path: root/TAO/TAO_IDL/be_include
diff options
context:
space:
mode:
authorJohnny Willemsen <jwillemsen@remedy.nl>2012-01-20 09:39:50 +0000
committerJohnny Willemsen <jwillemsen@remedy.nl>2012-01-20 09:39:50 +0000
commit9ae2e42a72166b9cc03917176f94609b58362900 (patch)
tree430c0c327d04aa28c1de418ac9b12df10b533121 /TAO/TAO_IDL/be_include
parent01fe9142672f0d6ca191e7f4e8cbc6a95762385d (diff)
downloadATCD-9ae2e42a72166b9cc03917176f94609b58362900.tar.gz
Diffstat (limited to 'TAO/TAO_IDL/be_include')
-rw-r--r--TAO/TAO_IDL/be_include/be_global.h20
1 files changed, 18 insertions, 2 deletions
diff --git a/TAO/TAO_IDL/be_include/be_global.h b/TAO/TAO_IDL/be_include/be_global.h
index ccbafd08853..9222c131750 100644
--- a/TAO/TAO_IDL/be_include/be_global.h
+++ b/TAO/TAO_IDL/be_include/be_global.h
@@ -818,6 +818,14 @@ public:
bool gen_skel_files (void) const;
void gen_skel_files (bool val);
+ /// Accessors for the member gen_svnt_cpp_files_.
+ bool gen_svnt_cpp_files (void) const;
+ void gen_svnt_cpp_files (bool val);
+
+ /// Accessors for the member gen_svnt_tpp_files_.
+ bool gen_svnt_tpp_files (void) const;
+ void gen_svnt_tpp_files (bool val);
+
/// Accessors for the member gen_client_inline_.
bool gen_client_inline (void) const;
void gen_client_inline (bool val);
@@ -1180,10 +1188,18 @@ private:
/// Separate files for generated Any operators?
bool gen_anyop_files_;
/// True by default, but a command line option can turn this off so
/// we generate only an empty *S.h file on the skeleton side.
bool gen_skel_files_;
+ /// True by default, but a command line option can turn this of so that
+ /// we don't generate a svnt.cpp file
+ bool gen_svnt_cpp_files_;
+
+ /// True by default, but a command line option can turn this of so that
+ /// we don't generate a svnt_T.cpp file
+ bool gen_svnt_tpp_files_;
+
/// True by default, but a command line option can turn this off so
/// that we don't generate a client inline file
bool gen_client_inline_;
@@ -1180,10 +1188,18 @@ private:
/// Separate files for generated Any operators?
bool gen_anyop_files_;
- /// True by default, but a command line option can turn this off so
- /// we generate only an empty *S.h file on the skeleton side.
+ /// True by default, but a command line option can turn this off so that
+ /// we don't generate a S.cpp file
bool gen_skel_files_;